%global ldb_modulesdir %(pkg-config --variable=modulesdir ldb)
%global ldb_version 1.1.4

%define servicename sssd
%define sssdstatedir %{_localstatedir}/lib/sss
%define dbpath %{sssdstatedir}/db
%define pipepath %{sssdstatedir}/pipes
%define pubconfpath %{sssdstatedir}/pubconf

%define major 0
%define libhbac %mklibname ipa_hbac %major
%define libsudo %mklibname sss_sudo %major
%define libautofs %mklibname sss_autofs %major

%define libsudodevel %mklibname -d sss_sudo %major 
%define libautofsdevel %mklibname -d sss_autofs %major
%define libhbacdevel %mklibname -d ipa_hbac %major

%define Werror_cflags %nil
%define _disable_ld_no_undefined 1

Name:       sssd
Version:    1.8.4
Release:    1
Group:      System/Libraries
Summary:    System Security Services Daemon
License:    GPLv3+
URL:        http://fedorahosted.org/sssd/
Source0:    https://fedorahosted.org/released/sssd/%{name}-%{version}.tar.gz
Patch0:     sssd-1.2.0-fix-linking.patch
Requires: sssd-client = %{version}-%{release}
Requires: sasl-plug-gssapi
BuildRequires: popt-devel
BuildRequires: libunistring-devel
BuildRequires: talloc-devel
BuildRequires: tevent-devel
BuildRequires: tdb-devel
BuildRequires: ldb-devel
BuildRequires: libnl-devel
BuildRequires: semanage-devel
BuildRequires: dbus-devel
BuildRequires: openldap-devel
BuildRequires: pam-devel
BuildRequires: nss-devel
BuildRequires: nspr-devel
BuildRequires: pcre-devel
BuildRequires: xsltproc
BuildRequires: libxml2
BuildRequires: docbook-style-xsl
BuildRequires: docbook-dtd44-xml
BuildRequires: krb5-devel
BuildRequires: c-ares-devel
BuildRequires: python-devel
BuildRequires: check-devel
BuildRequires: doxygen
BuildRequires: keyutils-devel
BuildRequires: bind-utils
BuildRequires: dhash-devel
BuildRequires: collection-devel
BuildRequires: ini_config-devel
BuildRequires: path_utils-devel

%description
Provides a set of daemons to manage access to remote directories and
authentication mechanisms. It provides an NSS and PAM interface toward
the system and a pluggable backend system to connect to multiple different
account sources. It is also the basis to provide client auditing and policy
services for projects like FreeIPA.

%package client
Summary: SSSD Client libraries for NSS and PAM
Group: System/Libraries
License: LGPLv3+

%description client
Provides the libraries needed by the PAM and NSS stacks to connect to the SSSD
service.

%package tools
Summary: Userspace tools for use with the SSSD
Group:	System/Base
License: GPLv3+
Requires: sssd = %{version}-%{release}

%description tools
Provides userspace tools for manipulating users, groups, and nested groups in
SSSD when using id_provider = local in /etc/sssd/sssd.conf.

Also provides a userspace tool for generating an obfuscated LDAP password for
use with ldap_default_authtok_type = obfuscated_password.



%package -n %libhbac
Summary: %summary
Group:  System/Libraries
Obsoletes: %{_lib}sssd < %{version}

%description -n %libhbac
Provides the libraries needed by the PAM and NSS stacks to connect to the SSSD
service.


%package -n %libautofs
Summary: A library to allow communication between Autofs and SSSD
Group: Development/C
License: LGPLv3+

%description -n %libautofs
A utility library to allow communication between Autofs and SSSD

%package -n %libsudo
Summary: A library to allow communication between SUDO and SSSD
Group: Development/C
License: LGPLv3+

%description -n %libsudo
A utility library to allow communication between SUDO and SSSD


%package -n %libhbacdevel
Summary: FreeIPA HBAC Evaluator library
Group: Development/C
License: LGPLv3+

%description -n %libhbacdevel
Utility library to validate FreeIPA HBAC rules for authorization requests

%package -n %libautofsdevel
Summary: A library to allow communication between Autofs and SSSD
Group: Development/C
License: LGPLv3+

%description -n %libautofsdevel
A utility library to allow communication between Autofs and SSSD

%package -n %libsudodevel
Summary: A library to allow communication between SUDO and SSSD
Group: Development/C
License: LGPLv3+

%description -n %libsudodevel
A utility library to allow communication between SUDO and SSSD


%package -n libhbac-python
Summary: Python bindings for the FreeIPA HBAC Evaluator library
Group: Development/C
License: LGPLv3+
Requires: %{libhbac} = %{version}-%{release}

%description -n libhbac-python
The libipa_hbac-python contains the bindings so that libipa_hbac can be
used by Python applications.


%prep
%setup -q
#patch0 -p 1
#autoreconf

%build
%configure2_5x \
    --with-db-path=%{dbpath} \
    --with-pipe-path=%{pipepath} \
    --with-pubconf-path=%{pubconfpath} \
    --with-init-dir=%{_initrddir} \
    --with-krb5-rcache-dir=%{_localstatedir}/cache/krb5rcache \
    --enable-nsslibdir=/%{_lib} \
    --enable-pammoddir=/%{_lib}/security \
    --disable-static \
    --disable-rpath \
    --with-test-dir=/dev/shm \
    --enable-all-experimental-features

%make

%install

%makeinstall_std

# Prepare language files
/usr/lib/rpm/find-lang.sh $RPM_BUILD_ROOT sssd

# Prepare empty config file
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sssd
touch $RPM_BUILD_ROOT/%{_sysconfdir}/sssd/sssd.conf

# Copy default logrotate file
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d
install -m644 src/examples/logrotate $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/sssd

# Make sure SSSD is able to run on read-only root
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/rwtab.d
install -m644 src/examples/rwtab $RPM_BUILD_ROOT%{_sysconfdir}/rwtab.d/sssd

# Replace sysv init script with systemd unit file
rm -f $RPM_BUILD_ROOT/%{_initrddir}/%{name}
mkdir -p $RPM_BUILD_ROOT/%{_unitdir}/
cp src/sysv/systemd/sssd.service $RPM_BUILD_ROOT/%{_unitdir}/

# Remove .la files created by libtool
find $RPM_BUILD_ROOT -name "*.la" -exec rm -f {} \;

# Suppress developer-only documentation
rm -Rf ${RPM_BUILD_ROOT}/%{_docdir}/%{name}/doc

# Older versions of rpmbuild can only handle one -f option
# So we need to append to the sssd.lang file
for file in `ls $RPM_BUILD_ROOT/%{python_sitelib}/*.egg-info 2> /dev/null`
do
    echo %{python_sitelib}/`basename $file` >> sssd.lang
done

touch sssd_tools.lang
for man in `find $RPM_BUILD_ROOT/%{_mandir}/??/man?/ -type f | sed -e "s#$RPM_BUILD_ROOT/%{_mandir}/##"`
do
    lang=`echo $man | cut -c 1-2`
    case `basename $man` in
        sss_*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_tools.lang
            ;;
        pam_sss*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_client.lang
            ;;
        sssd_krb5_locator_plugin*)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd_client.lang
            ;;
        *)
            echo \%lang\(${lang}\) \%{_mandir}/${man}\* >> sssd.lang
            ;;
    esac
done

# Print these to the rpmbuild log
echo "sssd.lang:"
cat sssd.lang

echo "sssd_client.lang:"
cat sssd_client.lang

echo "sssd_tools.lang:"
cat sssd_tools.lang

%post
%_post_service %{servicename}

%preun
%_preun_service %{servicename}

%files -f sssd.lang
%doc COPYING
%doc src/examples/sssd-example.conf
%{_unitdir}/sssd.service
%{_sbindir}/sssd

%{_libexecdir}/%{servicename}/krb5_child
%{_libexecdir}/%{servicename}/ldap_child
%{_libexecdir}/%{servicename}/proxy_child
%{_libexecdir}/%{servicename}/sssd_be
%{_libexecdir}/%{servicename}/sssd_nss
%{_libexecdir}/%{servicename}/sssd_pam
%{_libexecdir}/%{servicename}/sssd_autofs
%{_libexecdir}/%{servicename}/sssd_ssh
%{_libexecdir}/%{servicename}/sssd_sudo

%{_libdir}/%{name}/libsss_ipa.so
%{_libdir}/%{name}/libsss_krb5.so
%{_libdir}/%{name}/libsss_ldap.so
%{_libdir}/%{name}/libsss_proxy.so
%{_libdir}/%{name}/libsss_simple.so

%{ldb_modulesdir}/memberof.so

%{_bindir}/sss_ssh_authorizedkeys
%{_bindir}/sss_ssh_knownhostsproxy

%dir %{sssdstatedir}
%dir %{_localstatedir}/cache/krb5rcache
%attr(700,root,root) %dir %{dbpath}
%attr(755,root,root) %dir %{pipepath}
%attr(755,root,root) %dir %{pubconfpath}
%attr(700,root,root) %dir %{pipepath}/private
%attr(750,root,root) %dir %{_var}/log/%{name}
%attr(700,root,root) %dir %{_sysconfdir}/sssd
%ghost %attr(0600,root,root) %config(noreplace) %{_sysconfdir}/sssd/sssd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/sssd
%config(noreplace) %{_sysconfdir}/rwtab.d/sssd
%{_datadir}/sssd/sssd.api.conf
%{_datadir}/sssd/sssd.api.d
%{_mandir}/man1/sss_ssh_authorizedkeys.1*
%{_mandir}/man1/sss_ssh_knownhostsproxy.1*
%{_mandir}/man5/sssd.conf.5*
%{_mandir}/man5/sssd-ipa.5*
%{_mandir}/man5/sssd-krb5.5*
%{_mandir}/man5/sssd-ldap.5*
%{_mandir}/man5/sssd-simple.5*
%{_mandir}/man8/sssd.8*
%{python_sitearch}/pysss.so
%{python_sitelib}/*.py*

%files -n %libhbac
%{_libdir}/libipa_hbac.so.%{major}*

%files -n libhbac-python
%{python_sitearch}/pyhbac.so

%files -n %libhbacdevel
%{_includedir}/ipa_hbac.h
%{_libdir}/libipa_hbac.so
%{_libdir}/pkgconfig/ipa_hbac.pc

%files -n %libsudo
%{_libdir}/libsss_sudo.so.*

%files -n %libautofs
%{_libdir}/sssd/modules/libsss_autofs.so*

%files -n %libsudodevel
%{_includedir}/sss_sudo.h
%{_libdir}/libsss_sudo.so
%{_libdir}/pkgconfig/libsss_sudo.pc


%files tools -f sssd_tools.lang
%doc COPYING
%{_sbindir}/sss_useradd
%{_sbindir}/sss_userdel
%{_sbindir}/sss_usermod
%{_sbindir}/sss_groupadd
%{_sbindir}/sss_groupdel
%{_sbindir}/sss_groupmod
%{_sbindir}/sss_groupshow
%{_sbindir}/sss_obfuscate
%{_sbindir}/sss_cache
%{_sbindir}/sss_debuglevel
%{_mandir}/man8/sss_groupadd.8*
%{_mandir}/man8/sss_groupdel.8*
%{_mandir}/man8/sss_groupmod.8*
%{_mandir}/man8/sss_groupshow.8*
%{_mandir}/man8/sss_useradd.8*
%{_mandir}/man8/sss_userdel.8*
%{_mandir}/man8/sss_usermod.8*
%{_mandir}/man8/sss_obfuscate.8*
%{_mandir}/man8/sss_cache.8*
%{_mandir}/man8/sss_debuglevel.8*


%files client -f sssd_client.lang
%doc src/sss_client/COPYING src/sss_client/COPYING.LESSER
/%{_lib}/libnss_sss.so.2
/%{_lib}/security/pam_sss.so
%{_libdir}/krb5/plugins/libkrb5/sssd_krb5_locator_plugin.so
%{_mandir}/man8/pam_sss.8*
%{_mandir}/man8/sssd_krb5_locator_plugin.8*


%changelog
* Thu Jun 21 2012 Alexander Khrukin <akhrukin@mandriva.org> 1.8.4-1
+ Revision: 806652
- version update 1.8.4

* Fri Apr 20 2012 Alexander Khrukin <akhrukin@mandriva.org> 1.8.2-1
+ Revision: 792492
- broken group fix
- version update 1.8.2
- check section fix
- unistr.h BR added
- unistr.h BR added
- version update 1.7.0

  + Oden Eriksson <oeriksson@mandriva.com>
    - relink against libpcre.so.1

* Tue Feb 01 2011 Guillaume Rousse <guillomovitch@mandriva.org> 1.5.1-1
+ Revision: 634648
- new version

* Fri Dec 31 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.5.0-3mdv2011.0
+ Revision: 626831
- more dependencies fix

* Thu Dec 30 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.5.0-2mdv2011.0
+ Revision: 626422
- fix post/postun scripts
- drop explicit dependencies

* Tue Dec 28 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.5.0-1mdv2011.0
+ Revision: 625516
- new version

* Fri Nov 05 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.4.1-1mdv2011.0
+ Revision: 593703
- update to new version 1.4.1

* Wed Nov 03 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.4.0-2mdv2011.0
+ Revision: 592981
- new version

  + Michael Scherer <misc@mandriva.org>
    - fix build on 2.7
    - rebuild for python 2.7

* Sun Aug 08 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.3.0-1mdv2011.0
+ Revision: 567789
- new version
- import sssd

